==> prestashop-1.4.9.0.tbz: www/prestashop/mails/fr/lang.php <==
<?php

global $_LANGMAIL;
$_LANGMAIL = array();
$_LANGMAIL['Welcome!'] = 'Bienvenue !';
$_LANGMAIL['Message from contact form'] = 'Message depuis le formulaire de contact';
$_LANGMAIL['Your message has been correctly sent'] = 'Votre message a bien été envoyé';
$_LANGMAIL['New credit slip regarding your order'] = 'Nouvel avoir concernant votre commande';
$_LANGMAIL['Virtual product to download'] = 'Produit virtuel à télécharger';
$_LANGMAIL['Fwd: Customer message'] = 'TR: Message d\'un client';
$_LANGMAIL['Your guest account has been transformed to customer account'] = 'Votre compte invité a été transformé en compte client';
$_LANGMAIL['Package in transit'] = 'Livraison en cours';
$_LANGMAIL['Log: You have a new alert from your shop'] = '';
$_LANGMAIL['Order confirmation'] = 'Confirmation de commande';
$_LANGMAIL['Message from a customer'] = 'Message d\'un client';
$_LANGMAIL['New message regarding your order'] = 'Nouveau message concernant votre commande';
$_LANGMAIL['Your order return state has changed'] = 'Nouveau statut de commande';
$_LANGMAIL['Your new admin password'] = '';
$_LANGMAIL['Password query confirmation'] = 'Confirmation de demande de mot de passe';
$_LANGMAIL['An answer to your message is available'] = '';
$_LANGMAIL['New voucher regarding your order'] = 'Nouveau bon de réduction concernant votre commande';
$_LANGMAIL['Happy birthday!'] = 'Bon anniversaire !';
$_LANGMAIL['Newsletter confirmation'] = 'Confirmation newsletter';
$_LANGMAIL['Newsletter voucher'] = 'Bon de réduction newsletter';
$_LANGMAIL['Your wishlist\\\'s link'] = '';
$_LANGMAIL['Message from '] = 'Message de ';
$_LANGMAIL['Your cart and your discount'] = 'Votre panier et votre bon de réduction';
$_LANGMAIL['Thanks for your order'] = 'Merci pour votre commande';
$_LANGMAIL['You are one of our best customers'] = 'Vous êtes l\'un de nos meilleurs clients';
$_LANGMAIL['We miss you'] = 'Vous nous manquez';
$_LANGMAIL['Product available'] = 'Produit disponible';
$_LANGMAIL['Product out of stock'] = 'Rupture de stock';
$_LANGMAIL['Error reporting from your PayPal module'] = '';
$_LANGMAIL['Congratulations!'] = 'Bravo !';
$_LANGMAIL['Referral Program'] = 'Programme de parrainage';
$_LANGMAIL['A friend sent you a link to'] = 'Un ami vous a envoyé un lien vers';

?>

==> prestashop-1.5.3.1.tbz: www/prestashop/mails/fr/lang.php <==
<?php

global $_LANGMAIL;
$_LANGMAIL = array();

$_LANGMAIL['New credit slip regarding your order'] = 'Nouvel avoir concernant votre commande';
$_LANGMAIL['Message from a customer'] = 'Message d\'un client';
$_LANGMAIL['Your new password'] = 'Votre nouveau mot de passe';
$_LANGMAIL['Newsletter confirmation'] = 'Confirmation newsletter';
$_LANGMAIL['Email verification'] = 'Email de vérification';
$_LANGMAIL['Newsletter voucher'] = 'Bon de réduction newsletter';
$_LANGMAIL['Message from %1$s %2$s'] = 'Message de %1$s %2$s';
$_LANGMAIL['Your cart and your discount'] = 'Votre panier et votre bon de réduction';
$_LANGMAIL['Stock coverage'] = 'Couverture de stock';
$_LANGMAIL['%1$s sent you a link to %2$s'] = '%1$s vous a envoyé un lien vers %2$s';
$_LANGMAIL['Your guest account has been transformed to customer account'] = 'Votre compte invité a été transformé en compte client';
$_LANGMAIL['Process the payment of your order'] = 'Traiter le paiement de votre commande';
$_LANGMAIL['Package in transit'] = 'Livraison en cours';
$_LANGMAIL['Log: You have a new alert from your shop'] = 'Log : Vous avez un nouveau message d\'alerte dans votre boutique';
$_LANGMAIL['Password query confirmation'] = 'Confirmation de demande de mot de passe';
$_LANGMAIL['An answer to your message is available #ct%1$s #tc%2$s'] = 'Une réponse à votre message est disponible #ct%1$s #tc%2$s';
$_LANGMAIL['You are one of our best customers'] = 'Vous êtes l\'un de nos meilleurs clients';
$_LANGMAIL['Welcome!'] = 'Bienvenue !';
$_LANGMAIL['Virtual product to download'] = 'Produit virtuel à télécharger';
$_LANGMAIL['Fwd: Customer message'] = 'TR: Message d\'un client';
$_LANGMAIL['Order confirmation'] = 'Confirmation de commande';
$_LANGMAIL['New message regarding your order'] = 'Nouveau message concernant votre commande';
$_LANGMAIL['New voucher regarding your order %s'] = 'Nouveau bon de réduction concernant votre commande %s';
$_LANGMAIL['Thanks for your order'] = 'Merci pour votre commande';
$_LANGMAIL['We miss you'] = 'Vous nous manquez';
$_LANGMAIL['Congratulations!'] = 'Bravo !';
$_LANGMAIL['Your order return state has changed'] = 'Nouveau statut de commande';
$_LANGMAIL['Your message has been correctly sent'] = 'Votre message a bien été envoyé';
$_LANGMAIL['Your order has been changed'] = 'Votre commande a été modifiée';
$_LANGMAIL['Product available'] = 'Produit disponible';
$_LANGMAIL['Product out of stock'] = 'Rupture de stock';
$_LANGMAIL['Your wishlist\'s link'] = 'Lien vers votre liste de cadeaux';
$_LANGMAIL['Message from contact form'] = 'Message depuis le formulaire de contact';
